@@ -50,7 +50,7 @@ Q_OBJECT
 
   private:
     DCOPRef *dcopCall;
-    KCMultiDialog *settingsDialog = 0;
+    KCMultiDialog *settingsDialog;
 
 };
 
